==> data_manipulation-0.30.tar.gz: data_manipulation-0.30/README.md <==
# Data Manipulation

- [Data Manipulation](#data-manipulation)
  - [What is it?](#what-is-it)
  - [Where to get it](#where-to-get-it)
  - [Dependencies](#dependencies)
  - [License](#license)
  - [Getting Help](#getting-help)
  - [Discussion and Development](#discussion-and-development)
  - [Contributing to data manipulation](#contributing-to-data-manipulation)

My data manipulation library includes functions build on top of popular Python libraries such as Pandas, PySpark and more.

## What is it?

Data Manipulation is a Python package providing powerful utility functions. It contains many subpackages with utility functions built for popular packages such as Pandas, PySpark and many more.

## Where to get it

The source code is currently hosted on GitHub at: https://github.com/shawnngtq/data-manipulation

```bash
pip install data-manipulation
```

## Dependencies

The dependencies will be installed automatically along with this package

- beautifulsoup4
- django
- numpy
- pandas
- ipython
- requests
- psycopg2
- pyspark

## License

[BSD 3](LICENSE)

## Getting Help

For usage questions, the best place to go to is StackOverflow.

## Discussion and Development

Most development discussion is taking place on github in this repo.

## Contributing to data manipulation

All contributions, bug reports, bug fixes, documentation improvements, enhancements and ideas are welcome.

As contributors and maintainers to this project, you are expected to abide by our code of conduct. More information can be found at: [Contributor Code of Conduct](https://github.com/shawnngtq/data-manipulation/blob/master/CODE_OF_CONDUCT.md)

==> data_manipulation-0.49.tar.gz: data_manipulation-0.49/README.md <==
# Data Manipulation

- [Data Manipulation](#data-manipulation)
  - [What is it?](#what-is-it)
  - [Where to get it](#where-to-get-it)
  - [Dependencies](#dependencies)
  - [License](#license)
  - [Getting Help](#getting-help)
  - [Discussion and Development](#discussion-and-development)
  - [Contributing to data manipulation](#contributing-to-data-manipulation)

My data manipulation library includes functions build on top of popular Python libraries such as Pandas, PySpark and more.

## What is it?

Data Manipulation is a Python package providing powerful utility functions. It contains many subpackages with utility functions built for popular packages such as Pandas, PySpark and many more.

## Where to get it

The source code is currently hosted on GitHub at: https://github.com/shawnngtq/data-manipulation

```bash
pip install data-manipulation
```

## Dependencies

The dependencies will be installed automatically along with this package, in `setup.py`

## License

[BSD 3](LICENSE)

## Getting Help

For usage questions, the best place to go to is StackOverflow.

## Discussion and Development

Most development discussion is taking place on github in this repo.

## Contributing to data manipulation

All contributions, bug reports, bug fixes, documentation improvements, enhancements and ideas are welcome.

As contributors and maintainers to this project, you are expected to abide by our code of conduct. More information can be found at: [Contributor Code of Conduct](https://github.com/shawnngtq/data-manipulation/blob/master/CODE_OF_CONDUCT.md)
